# Unpublished Opinions

### Log of Unpublished Opinions

### Unpublished Opinions appear on this site by 1:00 p.m PT on the day of release

For Unpublished Opinions posted December 8, 2008 to November 10, 2009 click here.
Please contact the clerk's office at 415-355-8000 to find out how to obtain an unpublished opinion filed before 2008.

*: immediate filing o: order oa: order amending oad: oa dissent | oop: order & opinion o2: second opinion eb: en banc ebop: en banc opinion | ebo: en banc order cd: concurrence/dissent oad: order amend. dissent ad: amended dissent | s: supplemental opinion sd: supplemental dissent ao: amended opinion co: corrected opinion app: appendix

Published Within:

Search
by Case Title: |  |  |  |
by Case No.: |  |  |  |
by Case Panel: |  |  |  |
by Case Origin: |  |  |  |
by Case Type: |  |  |  |
by Date Filed (mm/dd/yyyy): |  |  |  |
Search type:

Results: 1 - 50 of 14,456 |
Pages: |<< << | 1, 2, 3, 4, ... | >> >>|
| Page size:

loading data...

Case Title | Case No. | Case Panel | Case Origin | Case Type | Case Code | Date Filed
--- | --- | --- | --- | --- | --- | ---
USA V. CAZARES | 06-50677 | PREGERSON, FLETCHER W. and Piersol | Los Angeles District Court | Criminal |  | 05/04/2013
TRISHAN AIR, INC. V. DASSAULT FALCON JET CORPORATIO | 11-56927 | KOZINSKI, CHIEF JUDGE, WARDLAW and GOULD | Los Angeles District Court | Civil |  | 05/04/2013
RAAFAT MOHAMMADKHANI V. JAMES ANTHONY | 11-15938 | FARRIS, SMITH N. R. and Burgess | Las Vegas District Court | Civil |  | 05/04/2013
USA V. MARK PARKER | 11-10247 | SCHROEDER, THOMAS and SILVERMAN | Sacramento District Court | Criminal |  | 05/04/2013
AMERICAN GUARANTEE AND LIABILI V. LEXINGTON INSURANCE COMPANY | 11-17130 | SCHROEDER, SILVERMAN and BEA | San Francisco District Court | Civil |  | 05/04/2013
USA V. ABILENE VELAZQUEZ-SEDANO | 12-50059 | RAWLINSON, BYBEE and Timlin | San Diego District Court | Criminal |  | 05/03/2013
KAUAI SCUBA CENTER, INC. V. PADI AMERICAS, INC. | 11-56346 | BERZON, TALLMAN and Rosenthal | Santa Ana District Court | Civil |  | 05/03/2013
USA V. ISMAEL RIVERA | 10-50180 | BERZON, TALLMAN and Rosenthal | Los Angeles District Court | Criminal |  | 05/03/2013
IVAN ALEKSEYEVETS V. CAROLYN W. COLVIN | 12-35079 | TASHIMA, CALLAHAN and Seabright | Seattle District Court | Civil |  | 05/02/2013
USA V. JUAN DE LA CRUZ-LOPEZ | 12-10120 | SCHROEDER, THOMAS and SILVERMAN | Tucson District Court | Criminal |  | 05/02/2013
MORTON BERGER V. THOMAS C. HORNE | 11-17316 | SCHROEDER, THOMAS and SILVERMAN | Phoenix District Court | Habeas |  | 05/02/2013
DEAN WHITE V. MICHAEL ASTRUE | 11-17306 | SCHROEDER, THOMAS and SILVERMAN | San Francisco District Court | Civil |  | 05/02/2013
RUBEN RUIZ V. EVERETT FISCHER | 10-17747 | SCHROEDER, THOMAS and SILVERMAN | San Francisco District Court | Prisoner |  | 05/02/2013
ROGER DEMING V. MERRILL LYNCH & CO INC | 11-35957 | NELSON D. W., CALLAHAN and Collins | Tacoma District Court | Civil |  | 05/01/2013
IN THE MATTER OF: FITNESS HOLDINGS INTERNATIONAL | 11-56677 | CALLAHAN, IKUTA and HURWITZ | Los Angeles District Court | Bankruptcy |  | 04/30/2013
USA V. EARL HARVEY | 12-50184 | BERZON, TALLMAN and SMITH M. | Los Angeles District Court | Criminal |  | 04/30/2013
NZIMBA MARQUES V. ERIC HOLDER, JR. | 11-71689 | KOZINSKI, CHIEF JUDGE, GRABER and CHRISTEN | Board of Immigration Appeals | Agency |  | 04/30/2013
PAUL COX, JR. V. KAREN POWERS | 11-56954 | BERZON, WATFORD and Carr | Riverside District Court | Habeas |  | 04/30/2013
EINSTEIN COSMETICS, LLC V. CVS CAREMARK CORP. | 11-56147 | FERNANDEZ, RAWLINSON and BYBEE | Los Angeles District Court | Civil |  | 04/30/2013
BARBARA BOYD V. MICHAEL ASTRUE | 11-36035 | TASHIMA, CALLAHAN and Seabright | Tacoma District Court | Civil |  | 04/30/2013
MARK BRIDGES V. LELAND MCEWEN | 09-56931 | BERZON, TALLMAN and SMITH M. | Los Angeles District Court | Habeas |  | 04/30/2013
USA V. JERONIMO BOTELLO-ROSALES | 12-30074 | PREGERSON, WARDLAW and SMITH M. | Portland District Court | Criminal |  | 04/29/2013
USA V. JUAN CRUZ-VALDIVIA | 12-50177 | PAEZ, WATFORD and Conlon | San Diego District Court | Criminal |  | 04/29/2013
CANDACE WALTERS V. ODYSSEY HEALTHCARE MANAGEMENT | 11-16762 | KOZINSKI, CHIEF JUDGE, GRABER and CHRISTEN | Phoenix District Court | Civil |  | 04/29/2013
SHABONDY SIMPSON V. M. EVANS | 11-15400 | NOONAN, FISHER and NGUYEN | Sacramento District Court | Habeas |  | 04/29/2013
USA V. JOSE VALENCIA-MENDOZA | 11-10616 | KOZINSKI, CHIEF JUDGE, O'SCANNLAIN and SMITH N. R. | Sacramento District Court | Criminal |  | 04/29/2013
ALICIA WOLIN V. CITY OF LOS ANGELES | 11-55817 | BERZON, WATFORD and Rakoff | Los Angeles District Court | Civil |  | 04/29/2013
SONAM BHUTIA V. ERIC H. HOLDER JR. | 08-73917 | SCHROEDER, SILVERMAN and BEA | Board of Immigration Appeals | Agency |  | 04/26/2013
TICKETMASTER, LLC V. ILLINOIS UNION INSURANCE COMPA | 11-56285 | BERZON, TALLMAN and SMITH M. | Los Angeles District Court | Civil |  | 04/26/2013
USA V. QUY NGUYEN | 12-30079 | NELSON D. W., TASHIMA and CALLAHAN | Seattle District Court | Criminal |  | 04/26/2013
USA V. WALTER RAUSINI | 11-10601 | SCHROEDER, THOMAS and SILVERMAN | San Francisco District Court | Criminal |  | 04/26/2013
SUERO-PERALTA V. USA | 07-35881 | TASHIMA, CALLAHAN and Seabright | Seattle District Court | Habeas |  | 04/26/2013
ZERO MOTORCYCLES, INC. V. PIRELLI TYRE S.P.A. | 11-16984 | SCHROEDER, SILVERMAN and BEA | Oakland District Court | Civil |  | 04/26/2013
U.S. PHILIPS CORPORATION V. USDC-CALA | 12-71696 | GOODWIN, WARDLAW and GOULD | Los Angeles District Court | Original Proceeding |  | 04/25/2013
USA V. QUAY PHIPPS | 12-50222 | REINHARDT, MURGUIA and Zouhary | Santa Ana District Court | Criminal |  | 04/25/2013
USA V. JAMAH BRIGGS | 12-50058 | WARDLAW, GOULD and Wolf | San Diego District Court | Criminal |  | 04/25/2013
PATRICK BERRY V. WEBLOYALTY.COM, INC. | 11-55764 | O'SCANNLAIN, FLETCHER W. and Korman | San Diego District Court | Civil |  | 04/25/2013
JASWINDER SINGH V. ERIC H. HOLDER JR. | 08-73921 | SCHROEDER, SILVERMAN and BEA | Board of Immigration Appeals | Agency |  | 04/25/2013
SO. CALIFORNIA DARTS ASSOC V. SO. CALIFORNIA DARTS ASSOC INC | 12-55951 | WARDLAW, GOULD and Wolf | Los Angeles District Court | Civil |  | 04/25/2013
XIU JIN V. ERIC H. HOLDER JR. | 08-74758 | NOONAN, O'SCANNLAIN and SMITH N. R. | Board of Immigration Appeals | Agency |  | 04/24/2013
JUAN HERNANDEZ REA V. ERIC H. HOLDER JR. | 08-74794 | RAWLINSON, BYBEE and Timlin | Board of Immigration Appeals | Agency |  | 04/24/2013
FRANCISCO OCAMPO CASTRO V. ERIC HOLDER, JR. | 10-72328 | NOONAN, O'SCANNLAIN and SMITH N. R. | Board of Immigration Appeals | Agency |  | 04/24/2013
USA V. JAN HEGER | 11-50473 | FERNANDEZ, RAWLINSON and BYBEE | Santa Ana District Court | Criminal |  | 04/24/2013
SEIU, UNITED HEALTHCARE WORKER V. CENTINELA HOSPITAL MEDICAL CEN | 11-56080 | REINHARDT, MURGUIA and Molloy | Los Angeles District Court | Civil |  | 04/24/2013
PEDRO MIRAMONTES V. OFFICER KLEVOS | 11-56641 | NOONAN, O'SCANNLAIN and SMITH N. R. | Santa Ana District Court | Prisoner |  | 04/24/2013
JOHN ZABASKY V. AMERICAN INTERNATIONAL GROUP | 11-57111 | FERNANDEZ, RAWLINSON and BYBEE | Los Angeles District Court | Civil |  | 04/24/2013
CANDIDA SANCHEZ-DE CABEZA V. ERIC HOLDER, JR. | 11-73998 | FERNANDEZ, RAWLINSON and BYBEE | Board of Immigration Appeals | Agency |  | 04/24/2013
PATRICK COLE V. J.E. THOMAS | 12-35678 | TALLMAN, SMITH M. and Rosenthal | Portland District Court | Habeas |  | 04/24/2013
USA V. AMALIA MONDRAGON-CARRILLO | 12-50111 | FERNANDEZ, RAWLINSON and BYBEE | San Diego District Court | Criminal |  | 04/24/2013
MICHAEL HUNT V. CITY OF LOS ANGELES | 12-55709 | GOODWIN, RAWLINSON and Seabright | Los Angeles District Court | Civil |  | 04/24/2013

Results: 1 - 50 of 14,456 |
Pages: |<< << | 1, 2, 3, 4, ... | >> >>|
| Page size:

- Electronic Filing - ECF
- Opinions
  - Published
  - Unpublished
- Calendar
  - Oral Arguments
  - Motions Panel
- Case Information
  - Dockets (PACER)
  - Pending En Banc Cases
- FAQs, Forms and
  Instructions
  - FAQs
  - After Opening a Case - Attorneys
  - After Opening a Case - Pro Se
  - Forms
  - Fee Schedule
  - Glossary
- Rules
  - FRAP & Circuit Rules
  - Streamlined Requests Replace Telephonic
    Requests for Extensions of Time
  - Electronic Submission of Excerpts
  - Proposed Rule Amendments
  - General Orders
- Guides and
  Legal Outlines
  - Ninth Circuit Immigration Outline
  - Appellate Jurisdiction in the Ninth Circuit
  - Standards of Review
  - Perfecting Your Appeal
  - How to File an Immigration Petition for Review
  - Section 1983 Outline
- Audio and Video
  - Audio
  - Video
- RSS Feeds

- Clerk's Office
- Mediation
- Appellate Commissioner
- Bankruptcy Appellate Panel

Welcome to the Internet portal of the United States Courts for the Ninth Circuit. more >> |  |
- Chief Judge Alex Kozinski

Site Map | Intranet (Judiciary Only) | COOP Staff Page | Seminar Disclosures | Judicial Misconduct |